import matplotlib.pyplot as plt
import numpy as np
import pandas as pd

df1 = pd.read_csv('experiments/augmentation_gan1_shift_2_aug_times_15_specnorm_G_0_specnorm_D_1_dist_gauss_bound_1.0_bound_eval_1.0_backup_z_no_aug_1_n_epochs_201/augmentation_gan1_shift_2_aug_times_15_specnorm_G_0_specnorm_D_1_dist_gauss_bound_1.0_bound_eval_1.0_backup_z_no_aug_1_n_epochs_201.csv')
df2 = pd.read_csv('experiments/augmentation_gan1_shift_8_aug_times_15_specnorm_G_0_specnorm_D_1_dist_gauss_bound_1.0_bound_eval_1.0_backup_z_no_aug_1_n_epochs_201/augmentation_gan1_shift_8_aug_times_15_specnorm_G_0_specnorm_D_1_dist_gauss_bound_1.0_bound_eval_1.0_backup_z_no_aug_1_n_epochs_201.csv')

n = 201 // 10 + 1
epochs = [ x * 10 for x in range(n)]

fig, axs = plt.subplots(3, 4, sharex=False, sharey=False, figsize=(16,12))

# marker symbol
axs[0, 0].plot(epochs, df1['lossg_wrt_z_mean'], 'k--', color='green')
axs[0, 0].plot(epochs, df2['lossg_wrt_z_mean'], 'k:', color='blue')
axs[0, 0].set_xlabel('epoch', fontsize='x-large')
axs[0, 0].set_ylabel(r'$\left\Vert \frac{\partial V_g}{\partial z} \right\Vert_2$', fontsize='xx-large')

axs[0, 1].plot(epochs, df1['d_wrt_gz_mean'], 'k--', color='green')
axs[0, 1].plot(epochs, df2['d_wrt_gz_mean'], 'k:', color='blue')
axs[0, 1].set_xlabel('epoch', fontsize='x-large')
axs[0, 1].set_ylabel(r'$\left\Vert \frac{\partial D}{\partial G(z)} \right\Vert_2$', fontsize='xx-large')

axs[0, 2].plot(epochs, df1['g_wrt_z_mean'], 'k--', color='green')
axs[0, 2].plot(epochs, df2['g_wrt_z_mean'], 'k:', color='blue')
axs[0, 2].set_xlabel('epoch', fontsize='x-large')
axs[0, 2].set_ylabel(r'$\left\Vert \frac{\partial G}{\partial z} \right\Vert_{\mathbf{F}}$', fontsize='xx-large')

axs[0, 3].plot(epochs, df1['fid_score'], 'k--', color='green', label=r'$\sigma=\sqrt{2}$')
axs[0, 3].plot(epochs, df2['fid_score'], 'k:', color='blue', label=r'$\sigma=\sqrt{24}$')
axs[0, 3].set_xlabel('epoch', fontsize='x-large')
axs[0, 3].set_ylabel('FID', fontsize='large')

axs[1, 0].plot(epochs, df1['lossg_mean'], 'k--', color='green')
axs[1, 0].plot(epochs, df2['lossg_mean'], 'k:', color='blue')
axs[1, 0].set_xlabel('epoch', fontsize='x-large')
axs[1, 0].set_ylabel(r'$V(G)$', fontsize='large')


axs[1, 1].plot(epochs, df1['acc'], 'k--', color='green')
axs[1, 1].plot(epochs, df2['acc'], 'k:', color='blue')
axs[1, 1].set_xlabel('epoch', fontsize='x-large')
axs[1, 1].set_ylabel(r'$acc$', fontsize='large')

axs[1, 2].plot(epochs, df1['lossd_mean'], 'k--', color='green')
axs[1, 2].plot(epochs, df2['lossd_mean'], 'k:', color='blue')
axs[1, 2].set_xlabel('epoch', fontsize='x-large')
axs[1, 2].set_ylabel(r'$V(D)$', fontsize='large')

axs[1, 3].plot(epochs, df1['dgz_mean']*-1, 'k--', color='green')
axs[1, 3].plot(epochs, df2['dgz_mean']*-1, 'k:', color='blue')
axs[1, 3].set_xlabel('epoch', fontsize='x-large')
axs[1, 3].set_ylabel(r'$-D(G(z))$', fontsize='large')

axs[2, 0].plot(epochs, df1['dx_mean'], 'k--', color='green')
axs[2, 0].plot(epochs, df2['dx_mean'], 'k:', color='blue')
axs[2, 0].set_xlabel('epoch', fontsize='x-large')
axs[2, 0].set_ylabel(r'$D(x)$', fontsize='large')

axs[2, 1].plot(epochs, df1['lossg_wrt_theta_g_mean'], 'k--', color='green')
axs[2, 1].plot(epochs, df2['lossg_wrt_theta_g_mean'], 'k:', color='blue')
axs[2, 1].set_xlabel('epoch', fontsize='x-large')
axs[2, 1].set_ylabel(r'$\left\Vert \frac{\partial V(G)}{\partial \theta_g} \right\Vert_{\mathbf{F}}$', fontsize='large')

axs[2, 2].plot(epochs, df1['lossd_wrt_theta_d_mean'], 'k--', color='green')
axs[2, 2].plot(epochs, df2['lossd_wrt_theta_d_mean'], 'k:', color='blue')
axs[2, 2].set_xlabel('epoch', fontsize='x-large')
axs[2, 2].set_ylabel(r'$\left\Vert \frac{\partial V(D)}{\partial \theta_d} \right\Vert_{\mathbf{F}}$', fontsize='large')

handles, labels = axs[0, 3].get_legend_handles_labels()
fig.legend(handles, labels, loc='lower right', fontsize = 'large')
plt.tight_layout()
plt.savefig('reports/augmentation_gan1.pdf')
